function a = simup(p,w,b)
%SIMUP Simulate perceptron layer.
%	
%	This function is obselete.
%	Use NNT2P and SIM to update and simulate your network.

nntobsf('simup','Use NNT2P and SIM to update and simulate your network.')

%	SIMUP(P,W,B)
%	  P - RxQ matrix of input (column) vectors.
%	  W - SxR weight matrix.
%	  B - Sx1 bias (column) vector.
%	Returns outputs of the perceptron layer.
%	
%	EXAMPLE: [w,b] = initp([0 1;-5 5],3);
%	         p = [2; -3];
%	         a = simup(p,w,b)
%	
%	See also NNSIM, PERCEPT, HARDLIM, INITP, LEARNP, TRAINP

% Mark Beale, 12-15-93
% Copyright (c) 1992-1998 by The MathWorks, Inc.
% $Revision: 1.7 $  $Date: 1998/06/11 17:22:43 $

if nargin < 2,error('Not enough arguments.'),end

a = hardlim(w*p,b);
